==> fispro_3.4.orig.tar.gz: fispro-3.4/cpp/fisopt/optdto.cpp <==
//***********************************************************************
//
//
//
//
// Author(s) : Serge GUILLAUME, Brigitte CHARNOMORDIC 
// FISPRO Version : 3.2 - Copyright INRA - Cemagref - 2002 - IDDN.FR.001.030024.000.R.P.2005.003.31235
// Licence http://www.cecill.info/licences/Licence_CeCILL_V2-en.html/
// Last modification date:  July 31, 2009 - Contact : fispro@supagro.inra.fr
//**********************************************************************
/*! \file optdto.cpp
 *  *  \brief This File contents the definition of the Optimizer member function DoubleToObject.
 *
 */
/*!
 * \fn int  sifopt::DoubleToObject ( double * Array , int size , vkey * Key ,void * P )
 * \brief This function rebuilds a FIS  whith a Set of double and the key.
 * \param Array set of double to fill
 * \param size the size of the array
 * \param Key A quiet complicated boolean string to tell what part of the FIS to update
 * \param P The adress of Your object
 * \return 0
 */
#include "sifopt.h"
int  sifopt::DoubleToObject ( double * Array , int size , vkey * Key ,void * P ){
#ifdef DEBUG
  printf("\n+DC Tests constraints size %i", size);
#endif
  
  if ( testConstraints( Array , size , Key  ) == -1 ) 
    {
      return -1; 
    }
  FIS  *S=( FIS * )P;
  FISIN * newI , * oldI;
  FISOUT * newO , * oldO;
  int cptActiveInput=0,ret;
  int Cpt;
if ( IsInput == 1 )
 {
  for ( int NumEntry = 0 ; NumEntry < nbEntree ; NumEntry ++ )
    {
      if  ( S->In[NumEntry]->IsActive() == false ) continue;
      oldI=S->In[NumEntry];
      try {
          newI = new FISIN( InputCenters[NumEntry] , InputCentersType[NumEntry],
                        InputNbMf[NumEntry] ,    oldI->min() , oldI->max(),oldI->OLower,oldI->OUpper  , PFFIn.Value[cptActiveInput]);
      cptActiveInput++;
      //bch-add original names to optimized MFs
      for (int imf=0;imf<(newI->GetNbMf());imf++)
	{
	  newI->GetMF(imf)->SetName(oldI->GetMF(imf)->Name);
	}
          }
      catch( std::exception &e )
          {
#ifdef DEBUG
           printf( "Catch %s", e.what() );
#endif
	   printf( "Catch %s", e.what() );
           return -1;
          }
      newI->SetName(oldI->Name);
      newI->Activate();
      delete S->In[NumEntry];
      S->In[NumEntry] = newI;
    };
  // fin boucle entree
 } else
if ( IsInput == 0 )
 {
     oldO=S->Out[numOutput];
      try {
      newO= new OUT_FUZZY(InputCenters[nbEntree] , InputCentersType[nbEntree] ,OutputNbMf,  oldO->min(), oldO->max() ,oldO->OLower,oldO->OUpper , PFFOut , oldO->Defuzzify(),oldO->Disjunct(), oldO->Classification(), oldO->DefaultValue() );
          }
      catch( std::exception &e )
          {
#ifdef DEBUG
           printf( "Catch %s", e.what() );
#endif
           return -1;
          }
      newO->SetName(oldO->Name);
      newO->Activate();
      delete S->Out[numOutput];
      S->Out[numOutput] = newO;
      // init Possibles and Classes arrays
      ret=S->ClassCheckNoAllocResClassif(Exemples,nbRow,numOutput);
 };
if ( IsInput == 2 )
 {
#ifdef DEBUG
  printf ("\n+DTO regles ");
#endif
  
   for ( Cpt = 0 ; Cpt < S->GetNbRule() ; Cpt++ )
       {
       S->Rule[Cpt]->SetAConc(numOutput,InputCenters[nbEntree+1][Cpt]);
       }
       S->Out[numOutput]->InitPossibles(S->Rule,S->GetNbRule(),numOutput);
 };
#ifdef DEBUG
  printf ( "\n apres transormation " );
  S->PrintCfg();
  printf ( "\n " );
#endif
  return 0;
}

==> fispro_3.6.orig.tar.gz: fispro-3.6/cpp/fisopt/optdto.cpp <==
//***********************************************************************
//
//
//
//
// Author(s) : Serge GUILLAUME, Brigitte CHARNOMORDIC 
// FISPRO Version : 3.2 - Copyright INRA - Cemagref - 2002 - IDDN.FR.001.030024.000.R.P.2005.003.31235
// Licence http://www.cecill.info/licences/Licence_CeCILL_V2-en.html/
// Last modification date:  July 31, 2009 - Contact : fispro@supagro.inra.fr
//**********************************************************************
/*! \file optdto.cpp
 *  *  \brief This File contents the definition of the Optimizer member function DoubleToObject.
 *
 */
/*!
 * \fn int  sifopt::DoubleToObject ( double * Array , int size , vkey * Key ,void * P )
 * \brief This function rebuilds a FIS  whith a Set of double and the key.
 * \param Array set of double to fill
 * \param size the size of the array
 * \param Key A quiet complicated boolean string to tell what part of the FIS to update
 * \param P The adress of Your object
 * \return 0
 */
#include "sifopt.h"
int  sifopt::DoubleToObject ( double * Array , int size , vkey * Key2 ,void * P ){
#ifdef DEBUG
  printf("\n+DC Tests constraints size %i", size);
#endif
  
  if ( testConstraints( Array , size) == -1 ) 
    {
      //printf("pb ici\n");
      return -1; 
    }
  FIS  *S=( FIS * )P;
  FISIN * newI , * oldI;
  FISOUT * newO , * oldO;
  int cptActiveInput=0,ret;
  int Cpt;
  int ptype=0,nMF,indKey=0;
  int *pType=NULL;
  double tol=0.001;
  
if ( IsInput == 1 )
 {
  for ( int NumEntry = 0 ; NumEntry < nbEntree ; NumEntry ++ )
    {
      if  ( S->In[NumEntry]->IsActive() == false ) continue;
      oldI=S->In[NumEntry];
  
      try {
          newI = new FISIN( InputCenters[NumEntry] , InputCentersType[NumEntry],
                        InputNbMf[NumEntry] ,    oldI->min() , oldI->max(),oldI->OLower,oldI->OUpper  , PFFIn.Value[cptActiveInput]);
      cptActiveInput++;
      //bch-add original names to optimized MFs
      for (int imf=0;imf<(newI->GetNbMf());imf++)
	{
	  newI->GetMF(imf)->SetName(oldI->GetMF(imf)->Name);
	}
          }
      catch( std::exception &e )
          {
#ifdef DEBUG
           printf( "Catch %s", e.what() );
#endif
	   printf( "Catch %s", e.what() );
           return -1;
          }
      newI->SetName(oldI->Name);
      newI->Activate();
      delete S->In[NumEntry];
      S->In[NumEntry] = newI;
    };
  // end input loop
 } else
  if ( IsInput == 0 )//output
 {
     oldO=S->Out[numOutput];
   
      try {
	
      newO= new OUT_FUZZY(InputCenters[nbEntree] , InputCentersType[nbEntree] ,OutputNbMf,  oldO->min(), oldO->max() ,oldO->OLower,oldO->OUpper , PFFOut , oldO->Defuzzify(),oldO->Disjunct(), oldO->Classification(), oldO->DefaultValue() );
          }
      catch( std::exception &e )
          {
#ifdef DEBUG
           printf( "Catch %s", e.what() );
#endif
           return -1;
          }
      newO->SetName(oldO->Name);
      newO->Activate();
      delete S->Out[numOutput];
      S->Out[numOutput] = newO;
      // init Possibles and Classes arrays
      ret=S->ClassCheckNoAllocResClassif(Exemples,nbRow,numOutput);
 };
if ( IsInput == 2 )
 {
#ifdef DEBUG
  printf ("\n+DTO regles ");
#endif
  
   for ( Cpt = 0 ; Cpt < S->GetNbRule() ; Cpt++ )
       {
       S->Rule[Cpt]->SetAConc(numOutput,InputCenters[nbEntree+1][Cpt]);
       }
       S->Out[numOutput]->InitPossibles(S->Rule,S->GetNbRule(),numOutput);
 };
#ifdef DEBUG
  printf ( "\n apres transormation " );
  S->PrintCfg();
  printf ( "\n " );
#endif
  return 0;
}
